LabelUpdateTask class

Updates the native Android and iOS application labels.

This task writes the configured app_name into Android AndroidManifest.xml and iOS Info.plist so the app displays the correct name on the launcher.

Inheritance

Constructors

LabelUpdateTask(RebrandConfig config)

Properties

config RebrandConfig
final
hashCode int
The hash code for this object.
no setterinherited
name String
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

execute() Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited