PackageRenameTask class

Renames the Android and iOS package/bundle identifiers.

This task uses change_app_package_name to apply the new package name from RebrandConfig.packageName across both Android and iOS.

Inheritance

Constructors

PackageRenameTask(RebrandConfig config)

Properties

config RebrandConfig
final
hashCode int
The hash code for this object.
no setterinherited
name String
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

execute() Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited