RebrandTask class abstract

A unit of work executed by RebrandService.

Each task should expose a human-readable name used by the CLI output and implement execute to perform a single piece of the rebranding process.

Implementers

Constructors

RebrandTask()

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

execute() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited