CliOptions class

Constructors

CliOptions({String? projectPath, String configPath = 'rebrand_config.json', bool showHelp = false, bool showVersion = false})
const
CliOptions.parse(List<String> args)
factory

Properties

configPath String
final
hashCode int
The hash code for this object.
no setterinherited
projectPath String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showHelp bool
final
showVersion bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited