CliOptions class
Parsed command-line options for the Rebrand CLI.
Includes path selection, config file path, help/version flags, and explicit
action flags such as --rename, --label, --launcher, and --splash.
Constructors
Properties
- configPath → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- labelOnly → bool
-
final
- launcherOnly → bool
-
final
- projectPath → String?
-
final
- renameOnly → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showHelp → bool
-
final
- showVersion → bool
-
final
- splashOnly → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited