AssetGenerationTask class
Shared asset generation utilities for launcher icons and splash screens.
This task can build helper YAML configs, pad splash images for Android 12, and execute the bitmaps generation steps when both icon and splash assets are required together.
- Inheritance
-
- Object
- RebrandTask
- AssetGenerationTask
Constructors
- AssetGenerationTask(RebrandConfig config)
Properties
- config → RebrandConfig
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
execute(
) → Future< void> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
buildLauncherIconYaml(
RebrandConfig config, String imagePath) → String -
buildSplashYaml(
RebrandConfig config, {required String imagePath, String? darkImagePath, required String android12ImagePath, String? android12DarkImagePath}) → String -
prepareSplashImage(
String? sourcePath, String outputPath, {required RebrandConfig config}) → String? -
processImage(
String iconPath, {double scaling = 0.65}) → Image -
writeAndRunIcons(
RebrandConfig config, String imagePath) → Future< void> -
writeAndRunSplash(
{required RebrandConfig config, required String imagePath, String? darkImagePath, required String android12ImagePath, String? android12DarkImagePath}) → Future< void>