RebrandTask class abstract
A unit of work executed by RebrandService.
Each task should expose a human-readable name used by the CLI output and implement execute to perform a single piece of the rebranding process.
Constructors
Properties
Methods
-
execute(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited