SetupDependenciesTask class
Ensures required worker packages are available for the selected actions.
It inspects the requested RebrandAction set and adds missing dev
dependencies such as change_app_package_name, flutter_launcher_icons,
or flutter_native_splash to the project.
- Inheritance
-
- Object
- RebrandTask
- SetupDependenciesTask
Constructors
-
SetupDependenciesTask(RebrandConfig config, {required Set<
RebrandAction> actions})
Properties
-
actions
→ Set<
RebrandAction> -
final
- config → RebrandConfig
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
execute(
) → Future< void> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited